@@ -15,10 +15,12 @@ from qtpy import QT_VERSION
 # 1. MAJOR version when you make incompatible API changes;
 # 2. MINOR version when you add functionality in a backwards-compatible manner;
 # 3. PATCH version when you make backwards-compatible bug fixes.
+
 __version__ = "5.0.1"
 
 # 2 扩展的更灵活的labelme，兼容官方的功能，但有更强的可视化效果，能查看shape的多个属性值
-__appname__ = "xllabelme v2.1.3"
+version = '2.1.8'
+__appname__ = f"xllabelme v{version}"
 
 QT4 = QT_VERSION[0] == "4"
 QT5 = QT_VERSION[0] == "5"
